Package: shinydisconnect
Title: Show a Nice Message When a 'Shiny' App Disconnects or Errors
Version: 0.1.1
Authors@R: person(given = "Dean", family = "Attali",
    email = "daattali@gmail.com",
    role = c("aut", "cre", "cph"),
    comment = c(ORCID="0000-0002-5645-3493"))
Description: A 'Shiny' app can disconnect for a variety of reasons: an unrecoverable error occurred in
    the app, the server went down, the user lost internet connection, or any other reason
    that might cause the 'Shiny' app to lose connection to its server. With 'shinydisconnect', you can
    call disonnectMessage() anywhere in a Shiny app's UI to add a nice message when this happens. 
    Works locally (running Shiny apps within 'RStudio') and on Shiny servers (such as shinyapps.io,
    'RStudio Connect', 'Shiny Server Open Source', 'Shiny Server Pro'). See demo online at 
    <https://daattali.com/shiny/shinydisconnect-demo/>.
URL: https://github.com/daattali/shinydisconnect,
        https://daattali.com/shiny/shinydisconnect-demo/
BugReports: https://github.com/daattali/shinydisconnect/issues
Imports: checkmate, glue, htmltools, shiny (>= 1.0)
Suggests: colourpicker
Depends: R (>= 3.0.0)
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-08-20 04:01:54 UTC; Dean-X1C
Author: Dean Attali [aut, cre, cph] (<https://orcid.org/0000-0002-5645-3493>)
Maintainer: Dean Attali <daattali@gmail.com>
Repository: CRAN
Date/Publication: 2023-08-21 08:30:07 UTC
Built: R 4.6.0; ; 2026-04-28 16:26:55 UTC; unix
